@@ -18,15 +18,17 @@
  */
 package org.apache.myfaces.renderkit.html;
 
+import javax.faces.context.FacesContext;
+
 import org.apache.myfaces.buildtools.maven2.plugin.builder.annotation.JSFRenderer;
-import org.apache.myfaces.shared_impl.renderkit.html.HtmlGroupRendererBase;
+import org.apache.myfaces.shared.renderkit.html.HtmlGroupRendererBase;
 
 
 /**
  *   
  * @author Thomas Spiegl (latest modification by $Author: lu4242 $)
  * @author Manfred Geiler
- * @version $Revision: 693358 $ $Date: 2008-09-08 22:54:29 -0500 (Mon, 08 Sep 2008) $
+ * @version $Revision: 1230371 $ $Date: 2012-01-12 02:09:45 +0000 (Thu, 12 Jan 2012) $
  */
 @JSFRenderer(
     renderKitId="HTML_BASIC",
@@ -35,4 +37,16 @@ import org.apache.myfaces.shared_impl.renderkit.html.HtmlGroupRendererBase;
 public class HtmlGroupRenderer
     extends HtmlGroupRendererBase
 {
+    @Override
+    protected boolean isCommonPropertiesOptimizationEnabled(FacesContext facesContext)
+    {
+        return true;
+    }
+
+    @Override
+    protected boolean isCommonEventsOptimizationEnabled(FacesContext facesContext)
+    {
+        return true;
+    }
+
 }
