@@ -18,12 +18,12 @@
  */
 package org.apache.myfaces.taglib.core;
 
-import org.apache.myfaces.shared_impl.taglib.core.SelectItemTagBase;
+import org.apache.myfaces.shared.taglib.core.SelectItemTagBase;
 
 
 /**
- * @author Manfred Geiler (latest modification by $Author: skitching $)
- * @version $Revision: 684465 $ $Date: 2008-08-10 06:38:21 -0500 (Sun, 10 Aug 2008) $
+ * @author Manfred Geiler (latest modification by $Author: bommel $)
+ * @version $Revision: 1187701 $ $Date: 2011-10-22 12:21:54 +0000 (Sat, 22 Oct 2011) $
  */
 public class SelectItemTag
         extends SelectItemTagBase
