@@ -40,6 +40,7 @@ import javax.faces.component.UIComponentBase;
 import javax.faces.component.UINamingContainer;
 import javax.faces.component.visit.VisitCallback;
 import javax.faces.component.visit.VisitContext;
+import javax.faces.component.visit.VisitHint;
 import javax.faces.component.visit.VisitResult;
 import javax.faces.context.FacesContext;
 import javax.faces.event.AbortProcessingException;
@@ -66,7 +67,7 @@ public class UIRepeat extends UIComponentBase implements NamingContainer
 
     public static final String COMPONENT_FAMILY = "facelets";
     
-    private static final String SKIP_ITERATION_HINT = "javax.faces.visit.SKIP_ITERATION";
+    //private static final String SKIP_ITERATION_HINT = "javax.faces.visit.SKIP_ITERATION";
 
     private final static DataModel<?> EMPTY_MODEL = new ListDataModel<Object>(Collections.emptyList());
     
@@ -1106,108 +1107,105 @@ public class UIRepeat extends UIComponentBase implements NamingContainer
         // override the behavior from UIComponent to visit
         // all children once per "row"
         
-        Boolean skipIterationHint = (Boolean) context.getFacesContext().getAttributes().get(SKIP_ITERATION_HINT);
+        //(Boolean) context.getFacesContext().getAttributes().get(SKIP_ITERATION_HINT);
+        Boolean skipIterationHint = context.getHints().contains(VisitHint.SKIP_ITERATION);
         if (skipIterationHint != null && skipIterationHint.booleanValue())
         {
             return super.visitTree(context, callback);
         }
-        pushComponentToEL(context.getFacesContext(), this);
-        try
-        {
         
-            if (!isVisitable(context))
+        if (!isVisitable(context)) 
+        {
+            return false;
+        }
+        
+        // save the current index, count aside
+        final int prevIndex = _index;
+        final int prevCount = _count;
+        
+        // validate attributes
+        _validateAttributes();
+        
+        // reset index and save scope values
+        _captureScopeValues();
+        _setIndex(-1);
+        
+        // push the Component to EL
+        pushComponentToEL(context.getFacesContext(), this);
+        try 
+        {
+            VisitResult res = context.invokeVisitCallback(this, callback);
+            switch (res) 
             {
+            // we are done, nothing has to be processed anymore
+            case COMPLETE:
+                return true;
+
+            case REJECT:
                 return false;
-            }
 
-            // save the current index, count aside
-            final int prevIndex = _index;
-            final int prevCount = _count;
-
-            // validate attributes
-            _validateAttributes();
-
-            // reset index and save scope values
-            _captureScopeValues();
-            _setIndex(-1);
-
-            try
-            {
-                VisitResult res = context.invokeVisitCallback(this, callback);
-                switch (res)
+            //accept
+            default:
+                // determine if we need to visit our children
+                // Note that we need to do this check because we are a NamingContainer
+                Collection<String> subtreeIdsToVisit = context
+                        .getSubtreeIdsToVisit(this);
+                boolean doVisitChildren = subtreeIdsToVisit != null
+                        && !subtreeIdsToVisit.isEmpty();
+                if (doVisitChildren)
                 {
-                // we are done, nothing has to be processed anymore
-                case COMPLETE:
-                    return true;
-
-                case REJECT:
-                    return false;
-
-                //accept
-                default:
-                    // determine if we need to visit our children
-                    // Note that we need to do this check because we are a NamingContainer
-                    Collection<String> subtreeIdsToVisit = context
-                            .getSubtreeIdsToVisit(this);
-                    boolean doVisitChildren = subtreeIdsToVisit != null
-                            && !subtreeIdsToVisit.isEmpty();
-                    if (doVisitChildren)
+                    // visit the facets of the component
+                    if (getFacetCount() > 0) 
                     {
-                        // visit the facets of the component
-                        if (getFacetCount() > 0)
+                        for (UIComponent facet : getFacets().values()) 
                         {
-                            for (UIComponent facet : getFacets().values())
+                            if (facet.visitTree(context, callback)) 
                             {
-                                if (facet.visitTree(context, callback))
+                                return true;
+                            }
+                        }
+                    }
+                    
+                    // visit the children once per "row"
+                    if (getChildCount() > 0) 
+                    {
+                        int i = getOffset();
+                        int end = getSize();
+                        int step = getStep();
+                        end = (end >= 0) ? i + end : Integer.MAX_VALUE - 1;
+                        _count = 0;
+                        
+                        _setIndex(i);
+                        while (i < end && _isIndexAvailable())
+                        {
+                            for (int j = 0, childCount = getChildCount(); j < childCount; j++)
+                            {
+                                UIComponent child = getChildren().get(j);
+                                if (child.visitTree(context, callback)) 
                                 {
                                     return true;
                                 }
                             }
-                        }
-
-                        // visit the children once per "row"
-                        if (getChildCount() > 0)
-                        {
-                            int i = getOffset();
-                            int end = getSize();
-                            int step = getStep();
-                            end = (end >= 0) ? i + end : Integer.MAX_VALUE - 1;
-                            _count = 0;
-
+                            
+                            _count++;
+                            i += step;
+                            
                             _setIndex(i);
-                            while (i < end && _isIndexAvailable())
-                            {
-                                for (int j = 0, childCount = getChildCount(); j < childCount; j++)
-                                {
-                                    UIComponent child = getChildren().get(j);
-                                    if (child.visitTree(context, callback))
-                                    {
-                                        return true;
-                                    }
-                                }
-
-                                _count++;
-                                i += step;
-
-                                _setIndex(i);
-                            }
                         }
                     }
-                    return false;
                 }
-            }
-            finally
-            {
-                // restore the previous count, index and scope values
-                _count = prevCount;
-                _setIndex(prevIndex);
-                _restoreScopeValues();
+                return false;
             }
         }
-        finally
+        finally 
         {
             // pop the component from EL
             popComponentFromEL(context.getFacesContext());
+            
+            // restore the previous count, index and scope values
+            _count = prevCount;
+            _setIndex(prevIndex);
+            _restoreScopeValues();
         }
     }
 
